@@ -1,13 +1,14 @@
 library(dplyr)
-options(HTTPUserAgent="Mozilla/5.0 (Linux; Android 10; K) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/114.0.0.0 Safari/537.36")
 
-set.seed(120)
 x <- fechas_elecciones %>%
   filter(tipo_eleccion == "generales") %>%
   sample() %>%
   slice(1)
 
-data <- candidatos("senado", x$anno, x$mes, nivel = "municipio") %>%
+# data <- candidatos("senado", x$anno, x$mes, nivel = "municipio") %>%
+#   filter(codigo_provincia != "99")
+
+data <- candidatos("senado", "2023", "07", nivel = "municipio") %>%
   filter(codigo_provincia != "99")
 
 test_that("n_provincias function", {
