@@ -1,7 +1,5 @@
 library(dplyr)
-options(HTTPUserAgent="Mozilla/5.0 (Linux; Android 10; K) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/114.0.0.0 Safari/537.36")
 
-set.seed(120)
 x <- fechas_elecciones %>%
   filter(tipo_eleccion == "generales") %>%
   sample() %>%
